<?php
/**
 * A TaskHandlerInitializer filter for hubs
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2015 City Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class CityTaskHandlerInitializerFilter extends BaseCityFilter implements Filterable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this filter class
	 *
	 * @return	$filterInstance		An instance of this filter class
	 */
	public static final function createCityTaskHandlerInitializerFilter () {
		// Get a new instance
		$filterInstance = new CityTaskHandlerInitializerFilter();

		// Return the instance
		return $filterInstance;
	}

	/**
	 * Executes the filter with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 * @throws	FilterChainException	If the filter chain needs to be interrupted
	 * @todo	Add more tasks
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// Get city instance
		$cityInstance = CityObjectFactory::createCityInstance();

		// Get a new task handler instance
		$handlerInstance = ObjectFactory::createObjectByConfiguredName('task_handler_class');

		// Put the task handler in registry
		Registry::getRegistry()->addInstance('task_handler', $handlerInstance);

		// Prepare a package-tags initialization task for the listeners
		//$taskInstance = ObjectFactory::createObjectByConfiguredName('city_package_tags_init_task_class');

		// Register it
		//$handlerInstance->registerTask('package_tags_init', $taskInstance);

		/*
		 * Allow extra city-depending tasks, e.g. the bootstrapper city needs
		 * booting its DHT. DHTs are decentralized and are working on
		 * peer-to-peer basis.
		 */
		$cityInstance->addExtraTasks($handlerInstance);
	}
}

// [EOF]
?>
